@@ -220,7 +220,8 @@ def _bq_cell_magic(line, query):
             import ast
 
             params = _helpers.to_query_parameters(
-                ast.literal_eval("".join(args.params))
+                parameters=ast.literal_eval("".join(args.params)),
+                parameter_types=dict(),
             )
             query_params = dict()
             for p in params:
